@@ -89,6 +89,13 @@
 
 - (void)flushMailCaches;
 
+/* utilities */
+- (NSString *)imap4FolderNameForURL:(NSURL *)_url;
+- (NSString *)imap4FolderNameForURL:(NSURL *)_url removeFileName:(BOOL)_delfn;
+
+/* extensions methods */
+- (NSException *)enableExtension:(NSString *)_extension;
+
 /* folder operations */
 
 - (NSArray *)subfoldersForURL:(NSURL *)_url;
